@@ -2060,6 +2060,9 @@ sub fill_in {
 		Select                   => '',
 		yes                      => '', 
 		no                       => '', 
+		name                     => '', 
+		password                 => '', 
+		log_on                   => '', 
 		today                    => '', 
 		confirm_open_vocabulary  => '   ?',
 		confirm_close_vocabulary => ' ',
@@ -2112,6 +2115,9 @@ sub fill_in {
 		Select                   => 'Select',
 		yes                      => 'Yes', 
 		no                       => 'No', 
+		name                     => 'name', 
+		password                 => 'password', 
+		log_on                   => 'log on', 
 		confirm_open_vocabulary  => 'Open the vocabulary window?',
 		confirm_close_vocabulary => 'Your choice is',
 		session_terminated       => 'Logged off',
@@ -2164,6 +2170,9 @@ sub fill_in {
 		Select                   => 'Slection',
 		yes                      => 'Oui', 
 		no                       => 'Non', 
+		name                     => 'nom', 
+		password                 => 'mot de passe', 
+		log_on                   => 'connecter', 
 		confirm_open_vocabulary  => 'Ouvrir le vocabulaire?',
 		confirm_close_vocabulary => 'Vous avez choisi',
 		session_terminated       => 'Dconnect',
