@@ -775,6 +775,16 @@ sub draw_window_title {
 
 ################################################################################
 
+sub draw_logon_form {
+
+	my ($options) = @_;
+		
+	return $_SKIN -> draw_logon_form (@_);
+
+}
+
+################################################################################
+
 sub draw_form {
 
 	my ($options, $data, $fields) = @_;
